@@ -21,7 +21,14 @@ from unidecode import unidecode
 
 class Client:
     BASE_URL = "https://mobileapi.jumbo.com/"
-    DEFAULT_HEADERS = {"User-Agent": "Mozilla/5.0 (Macintosh; Intel Mac OS X 10.15; rv:81.0) Gecko/20100101 Firefox/81.0"}
+    DEFAULT_HEADERS = {
+        "User-Agent": "Mozilla/5.0 (Linux; Android 11; M2101K7AG) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/96.0.4664.45 Mobile Safari/537.36",
+        "Cache-Control": "no-cache",
+        "Content-Type": "application/json",
+        "Accept-Encoding": "gzip, deflate, br",
+        "Accept": "*/*",
+        "Connection": "keep-alive",
+    }
     TEMP_DIR = os.path.join(tempfile.gettempdir(), "Supermarket-Connector", "Debug", "JUMBO")
 
     def request(
@@ -269,8 +276,11 @@ class Client:
                 self.quantity = data.get("quantity")
                 self.images = self.__client.images.process(images_data)
 
-                self.bonus_start_date = date.fromtimestamp(bonus_data.get("fromDate", 0))
-                self.bonus_end_date = date.fromtimestamp(bonus_data.get("toDate", 0))
+                start_date = bonus_data.get("fromDate")
+                end_date = bonus_data.get("toDate")
+
+                self.bonus_start_date = date.fromtimestamp(int(start_date / 1000)) if not start_date is None else None
+                self.bonus_end_date = date.fromtimestamp(int(end_date / 1000)) if not end_date is None else None
                 self.bonus_period_description = bonus_data.get("validityPeriod")
                 self.bonus_segment_description = bonus_data.get("summary")
                 self.bonus_mechanism = bonus_data.get("tags", [{}])[0].get("text")
